@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheLogger.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: ApacheLogger.h 2716 2007-12-01 12:34:40Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_LOGGER_H
@@ -35,6 +35,7 @@
 #include "apr_strings.h"
 
 #include "Logger.h"
+#include "ApacheResponse.h"
 #include "TemporaryPool.h"
 
 
@@ -52,7 +53,7 @@ public:
         __attribute__((format(printf,5,6)))
 #endif
         ;
-    void info(const char *file, int line, request_rec *r,
+    void info(const char *file, int line, ApacheResponse::Handle *r,
               const char *format, ...)
 #ifdef __GNUC__
         __attribute__((format(printf,5,6)))
@@ -64,7 +65,7 @@ public:
         __attribute__((format(printf,5,6)))
 #endif
         ;
-    void warn(const char *file, int line, request_rec *r,
+    void warn(const char *file, int line, ApacheResponse::Handle *r,
               const char *format, ...)
 #ifdef __GNUC__
         __attribute__((format(printf,5,6)))
@@ -76,7 +77,7 @@ public:
         __attribute__((format(printf,5,6)))
 #endif
         ;
-    void error(const char *file, int line, request_rec *r,
+    void error(const char *file, int line, ApacheResponse::Handle *r,
                const char *format, ...)
 #ifdef __GNUC__
         __attribute__((format(printf,5,6)))
