@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2588 2007-10-20 10:51:51Z svn $
+ * $Id: ApacheResponse.h 2717 2007-12-01 17:32:02Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -42,12 +42,58 @@
 class ApacheResponseWriter;
 class ApacheRequestReader;
 
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+extern "C" {
+int ap_find_types(request_rec *);
+}
+#endif
+
 /**
  * @brief Apache のレスポンスを表すクラス．
  */
 class ApacheResponse: public Uncopyable {
 public:
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+    typedef struct Handle {
+        apr_pool_t *pool;
+        request_rec *r;
+        char *uri;
+        char *args;
+        conn_rec *connection;
+        int method_number;
+        int header_only;
+        table *headers_in;
+        table *headers_out;
+        table *subprocess_env;
+        char *filename;
+
+        Handle(apr_pool_t *pool_arg, request_rec *r_arg)
+          : pool(pool_arg),
+            r(r_arg),
+            uri(r->uri),
+            args(r->args),
+            connection(r->connection),
+            method_number(r->method_number),
+            header_only(r->header_only),
+            headers_in(r->headers_in),
+            headers_out(r->headers_out),
+            subprocess_env(r->subprocess_env),
+            filename(r->filename)
+        {
+
+        };
+    } Handle;
+
+#undef apr_table_get
+#undef apr_table_set
+#undef apr_table_setn
+#define apr_table_get ap_table_get
+#define apr_table_set ap_table_set
+#define apr_table_setn ap_table_setn
+#else
     typedef request_rec Handle;
+#endif
+
     typedef ApacheRequestReader  Reader;
     typedef ApacheResponseWriter Writer;
 
@@ -97,7 +143,21 @@ public:
     };
     static apr_sockaddr_t *get_remote_addr(Handle *r)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        apr_sockaddr_t *remote_addr;
+
+        if (apr_sockaddr_info_get(&remote_addr, r->connection->remote_ip,
+                                  APR_INET,
+                                  r->connection->remote_addr.sin_port,
+                                  0, r->pool) != APR_SUCCESS) {
+            // 失敗することは想定していないので
+            THROW(MESSAGE_BUG_FOUND);
+        }
+
+        return remote_addr;
+#else
         return r->connection->remote_addr;
+#endif
     };
     static const char *get_user_agent(Handle *r)
     {
@@ -121,43 +181,78 @@ public:
     };
     static int is_meets_condition(Handle *r)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        return ap_meets_conditions(r->r);
+#else
         return ap_meets_conditions(r);
+#endif
     };
     static int prepare_post_read(Handle *r)
     {
         int status;
 
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        if ((status = ap_setup_client_block(r->r, REQUEST_CHUNKED_ERROR)) != OK) {
+            return status;
+        }
+        if (ap_should_client_block(r->r) == 0) {
+            return HTTP_NO_CONTENT;
+        }
+#else
         if ((status = ap_setup_client_block(r, REQUEST_CHUNKED_ERROR)) != OK) {
             return status;
         }
         if (ap_should_client_block(r) == 0) {
             return HTTP_NO_CONTENT;
         }
-
+#endif
         return OK;
     };
     static void set_modified_time(Handle *r, apr_time_t time)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        ap_update_mtime(r->r, time);
+#else
         ap_update_mtime(r, time);
+#endif
     };
     static void set_last_modified(Handle *r, apr_time_t time)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        ap_set_last_modified(r->r);
+#else
         ap_set_last_modified(r);
+#endif
     };
     static void set_content_type(Handle *r)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        r->r->content_type = NULL;
+
+        // MEMO: run mod_mime{_magick} again
+        ap_find_types(r->r);
+
+        if (r->r->content_type == NULL) {
+            set_content_type(r, "application/octet-stream");
+        }
+#else
         r->content_type = NULL;
 
-        // run mod_mime{_magick} again
+        // MEMO: run mod_mime{_magick} again
         ap_run_type_checker(r);
 
         if (r->content_type == NULL) {
-            ap_set_content_type(r, "application/octet-stream");
+            set_content_type(r, "application/octet-stream");
         }
+#endif
     };
     static void set_content_type(Handle *r, const char *content_type)
     {
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+        r->r->content_type = content_type;
+#else
         ap_set_content_type(r, content_type);
+#endif
     };
     static void set_accept_ranges(Handle *r)
     {
