@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.h 2540 2007-07-21 15:21:47Z svn $
+ * $Id: ApacheResponseWriter.h 2712 2007-11-30 15:58:42Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_WRITER_H
@@ -38,6 +38,7 @@
 #include "apr_want.h"
 
 #include "ResponseWriter.h"
+#include "ApacheResponse.h"
 #include "Message.h"
 #include "Macro.h"
 
@@ -52,7 +53,7 @@ typedef struct ap_filter_t ap_filter_t;
 class ApacheResponseWriter: public ResponseWriter
 {
 public:
-    ApacheResponseWriter(request_rec *r);
+    ApacheResponseWriter(ApacheResponse::Handle *r);
     ApacheResponseWriter(ApacheResponseWriter& writer);
     ~ApacheResponseWriter();
     void write(const char *str, apr_size_t length)
@@ -79,15 +80,15 @@ public:
     };
     void finish();
 
-    static bool is_sendfile_enabled(request_rec *r);
-    static int sendfile(request_rec *r, apr_file_t *file,
+    static bool is_sendfile_enabled(ApacheResponse::Handle *r);
+    static int sendfile(ApacheResponse::Handle *r, apr_file_t *file,
                         apr_uint64_t length);
 
 private:
     static const apr_size_t IO_VECTOR_SIZE = RES_IO_VECTOR_SIZE;
 
     void flush();
-    static bool is_mmap_enabled(request_rec *r);
+    static bool is_mmap_enabled(ApacheResponse::Handle *r);
 
     conn_rec *connection_;
     apr_bucket_brigade *brigade_;
