@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Environment.h 2508 2007-07-06 22:47:18Z svn $
+ * $Id: Environment.h 2707 2007-11-28 15:32:04Z svn $
  *****************************************************************************/
 
 #ifndef ENVIRONMENT_H
@@ -38,6 +38,12 @@
 
 #include "mod_uploader_config.h"
 
+#ifdef APACHE_HTTPD_H
+#ifndef AP_SERVER_MAJORVERSION_NUMBER
+#define AP_SERVER_MAJORVERSION_NUMBER 1
+#endif
+#endif
+
 #ifndef __STDC_CONSTANT_MACROS
 #define __STDC_CONSTANT_MACROS
 #endif
