@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 2595 2007-10-22 14:36:13Z svn $
+ * $Id: FileWriter.h 2688 2007-11-18 03:00:26Z svn $
  *****************************************************************************/
 
 #ifndef FILE_WRITER_H
@@ -64,14 +64,17 @@ public:
      */
     void write(const void *buffer, apr_size_t size)
     {
+        apr_size_t write_size;
+
         if (size == 0) {
             return;
         }
 
-        if (write_impl(buffer, size) != size) {
+        write_size = size;
+        write(buffer, &write_size);
+        if (write_size != size) {
             THROW(MESSAGE_FILE_WRITE_FAILED);
         }
-        write_size_ += size;
     };
     /**
      * ファイルへの書き出しを行います．
@@ -83,7 +86,8 @@ public:
      */
     void write(const void *buffer, apr_size_t *size)
     {
-        write(buffer, *size);
+        *size = write_impl(buffer, *size);
+        write_size_ += *size;
     };
     /**
      * ファイルを閉じます．
