@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC2822Parser.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: RFC2822Parser.h 2685 2007-11-17 22:35:04Z svn $
  *****************************************************************************/
 
 #ifndef RFC2822_PARSER_H
@@ -39,12 +39,13 @@
 #include "MessageDigest5.h"
 
 
+template<class W> class Base64FileWriter;
 template<class R, class W> class MultipartMessageParser;
 
 /**
  * @brief RFC2822 形式の入力をパースするクラス．
  */
-template<class R, class W=Base64FileWriter<BasicFileWriter> >
+template<class R, class W=Base64FileWriter<> >
 class RFC2822Parser: public MultipartMessageParser<R, W>
 {
 public:
@@ -72,6 +73,24 @@ public:
      */
     apr_array_header_t *parse();
 
+    static content_t *get_content(apr_array_header_t *content_array,
+                                  const char *name)
+    {
+        return MultipartMessageParser<R, W>::get_content(content_array, name);
+    }
+    static content_t *get_text_content(apr_array_header_t *content_array,
+                                       apr_size_t index=0)
+    {
+        return MultipartMessageParser<R, W>::get_text_content(content_array,
+                                                              index);
+    }
+    static content_t *get_file_content(apr_array_header_t *content_array,
+                                       apr_size_t index=0)
+    {
+        return MultipartMessageParser<R, W>::get_file_content(content_array,
+                                                              index);
+    }
+
 private:
     typedef R PostReaderClass;
     typedef W FileWriterClass;
