@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2525M 2007-08-26 12:58:57Z (ローカル) $
+ * $Id: ReadLocker.h 2732 2007-12-09 06:31:18Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -54,9 +54,6 @@ public:
 
         try_count = 1;
         while (1) {
-            // curr_status の read がループ外に押し出されるのを防ぐ
-            MEMORY_BARRIER;
-
             curr_status = apr_atomic_read(lock);
             if (LIKELY(can_lock(curr_status))) {
                 new_status = curr_status + READ_COUNT_UINIT;
@@ -70,14 +67,16 @@ public:
             } else if (((try_count++ & TIMEOUT_CHECK_MASK) == 0) &&
                        should_timeout(curr_status)) {
                 // タイムアウトしたら age を増やす
-                new_status = ((curr_status & (~READ_COUNT_MASK)) |
-                              READ_COUNT_UINIT) + AGE_UINIT;
+                new_status = (curr_status & (~READ_COUNT_MASK)) | READ_COUNT_UINIT;
+                new_status += AGE_UINIT;
                 prev_status = apr_atomic_cas(lock, new_status, curr_status);
                 init(lock, new_status);
                 if (prev_status == curr_status) {
                     log_try_count("ReadLock(TIME OUT)",
                                   try_count, curr_status, new_status);
-                    status_ = new_status;
+#ifdef DEBUG_ReadWriteLocker
+                    is_process_timeout_ = true;
+#endif
                     return;
                 }
             }
@@ -95,11 +94,8 @@ public:
         lock = lock_;
         try_count = 1;
         while (1) {
-            // curr_status の read がループ外に押し出されるのを防ぐ
-            MEMORY_BARRIER;
-
             curr_status = apr_atomic_read(lock);
-            if (UNLIKELY(is_timeout(curr_status, status_))) {
+            if (UNLIKELY(is_others_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
                 log_try_count("ReadUnLock(TIME OUT)",
                               try_count, curr_status, curr_status);
