@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.h 2546 2007-08-03 12:31:37Z svn $
+ * $Id: ReadWriteLocker.h 2731 2007-12-09 06:26:13Z svn $
  *****************************************************************************/
 
 #ifndef READ_WRITE_LOCKER_H
@@ -48,6 +48,12 @@
 #include "Uncopyable.h"
 #include "Macro.h"
 
+#ifdef DEBUG_ReadWriteLocker
+// MEMO: テスト用にタイムアウト時間を短くする
+#undef LCK_TIMEOUT_SEC
+#define LCK_TIMEOUT_SEC 1
+#endif
+
 /**
  * @brief 読み書きロックの設定を集めたクラス．
  */
@@ -82,35 +88,60 @@ protected:
     static const apr_uint32_t READ_COUNT_UINIT  = 1 << READ_COUNT_SHIFT;
 
     static const apr_uint32_t TIMEOUT_CHECK_MASK= 0x1F;
-    static const apr_uint32_t TIMEOUT_SEC       = 300;
+    static const apr_uint32_t TIMEOUT_SEC       = LCK_TIMEOUT_SEC;
 
     /**
      * コンストラクタです．
      */
     ReadWriteLocker()
      : start_age_(INVALID_AGE)
+#ifdef DEBUG_ReadWriteLocker
+       ,
+       is_process_timeout_(false)
+#endif
     {
 
     };
 
+    // 注意: ReadWriteLocker 型のポインタ経由で使用されることはないので，
+    // デストラクタは virtual にしない．
+
     /**
      * ロック後の初期化を行います．
      *
      * @param[in] lock ロック変数
-     * @param[in] status ロックの状態
      */
     void init(apr_atomic_t *lock, apr_uint32_t status)
     {
         lock_ = lock;
         status_ = status;
     };
-    // 注意: ReadWriteLocker 型のポインタ経由で使用されることはないので，
-    // デストラクタは virtual にしない．
-
+    /**
+     * タイムアウト処理すべきかどうか判断します．
+     *
+     * @param[in] status ロックの状態
+     */
+    bool should_timeout(apr_uint32_t status);
+    /**
+     * 他のスレッドがタイムアウト処理したかどうか判断します．
+     *
+     * @param[in] curr_status 現在のロックの状態
+     * @param[in] prev_status 以前のロックの状態
+     */
+    bool is_others_timeout(apr_uint32_t curr_status, apr_uint32_t prev_status)
+    {
+        return (((curr_status ^ prev_status) & AGE_MASK) != 0);
+    };
+#ifdef DEBUG_ReadWriteLocker
+    bool is_process_timeout()
+    {
+        return is_process_timeout_;
+    };
+#endif
     /**
      * プロセッサーを明け渡します．
      */
-    void yield()
+    static void yield()
     {
 #if APR_HAS_THREADS
         // APR 0.x だと UNIX 環境の apr_thread_yield の中身は空なので
@@ -121,25 +152,13 @@ protected:
 #endif
 #endif
     };
-    /**
-     * タイムアウト処理すべきかどうか判断します．
-     *
-     * @param[in] status ロックの状態
-     */
-    bool should_timeout(apr_uint32_t status);
-    /**
-     * タイムアウトしたかどうか判断します．
-     *
-     * @param[in] curr_status 現在のロックの状態
-     * @param[in] prev_status 以前のロックの状態
-     */
-    bool is_timeout(apr_uint32_t curr_status, apr_uint32_t prev_status)
+    static apr_uint32_t get_age_count(apr_uint32_t status)
     {
-        return (((curr_status ^ prev_status) & AGE_MASK) != 0);
+        return ((status & AGE_MASK) >> AGE_SHIFT);
     };
     static apr_uint32_t get_read_count(apr_uint32_t status)
     {
-        return ((status >> READ_COUNT_SHIFT) & READ_COUNT_MASK);
+        return ((status & READ_COUNT_MASK) >> READ_COUNT_SHIFT);
     };
     static apr_uint32_t get_prefer_write(apr_uint32_t status)
     {
@@ -161,11 +180,21 @@ protected:
 #endif
     };
 
+    // MEMO: テスト用
+    friend void read_lock(void *data);
+    friend void write_lock(void *data);
+    template<class LockType> friend void lock_die(void *data1, void *data2);
+    friend void run_read(apr_pool_t *pool);
+    friend void run_write(apr_pool_t *pool);
+
     /** 読み出し中のスレッドの数へのポインタ */
     apr_atomic_t *lock_;
     apr_uint32_t start_age_;
     apr_time_t start_time_;
     apr_uint32_t status_;
+#ifdef DEBUG_ReadWriteLocker
+    bool is_process_timeout_;
+#endif
 };
 
 #endif
