@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2619 2007-11-02 16:25:07Z svn $
+ * $Id: UploadItem.h 2705 2007-11-25 01:22:41Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -58,7 +58,13 @@ public:
         apr_size_t      id;
         apr_size_t      index;
         apr_atomic_t    download_count;
-        bool            is_need_sync;
+        union {
+            struct {
+                bool    is_gzipped      : 1;
+                bool    is_need_sync    : 1;
+            };
+            bool        flags;
+        };
         apr_uint64_t    file_size;
         apr_time_t      mtime;
         char            date[ITM_MAX_DATE_SIZE];
@@ -72,7 +78,6 @@ public:
         char            comment[ITM_MAX_COMMENT_SIZE];
 
         header() {
-            // ゼロクリア
             memset(identifier, 0, sizeof(struct header));
 
             strncpy(identifier, PACKAGE_NAME, ITM_MAX_IDENTIFIER_SIZE-1);
@@ -85,77 +90,81 @@ public:
     const char *get_identifier() const
     {
         return header_.identifier;
-    }
+    };
     const char *get_version() const
     {
         return header_.version;
-    }
+    };
     apr_size_t get_id() const
     {
         return header_.id;
-    }
+    };
     apr_size_t get_index() const
     {
         return header_.index;
-    }
+    };
     apr_size_t get_download_count() const
     {
         return  apr_atomic_read
             (const_cast<apr_atomic_t *>(&(header_.download_count)));
-    }
+    };
     apr_uint64_t get_file_size() const
     {
         return header_.file_size;
-    }
+    };
     apr_time_t get_mtime() const
     {
         return header_.mtime;
-    }
+    };
     const char *get_date() const
     {
         return header_.date;
-    }
+    };
     const char *get_ip_address() const
     {
         return header_.ip_address;
-    }
+    };
     const char *get_file_name() const
     {
         return header_.file_name;
-    }
+    };
     const char *get_file_mime() const
     {
         return header_.file_mime;
-    }
+    };
     const char *get_file_ext() const
     {
         return header_.file_ext;
-    }
+    };
     const char *get_file_digest() const
     {
         return header_.file_digest;
-    }
+    };
     const char *get_remove_pass() const
     {
         return header_.remove_pass;
-    }
+    };
     const char *get_download_pass() const
     {
         return header_.download_pass;
-    }
+    };
     const char *get_comment() const
     {
         return header_.comment;
-    }
+    };
+    bool is_gzipped() const
+    {
+        return header_.is_gzipped;
+    };
     bool is_need_sync() const
     {
         return header_.is_need_sync;
-    }
+    };
     void increment_download_count()
     {
         (void)apr_atomic_inc(&(header_.download_count));
         header_.is_need_sync = true;
-    }
+    };
     /**
      * メモリを使ってインスタンスを生成します．
      *
