@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2525 2007-07-12 15:23:44Z svn $
+ * $Id: WriteLocker.h 2732 2007-12-09 06:31:18Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -59,7 +59,7 @@ public:
         while (1) {
             curr_status = apr_atomic_read(lock);
             if (get_read_count(curr_status) == NOT_LOCKED) {
-                new_status = curr_status | WRITE_LOCKED;
+                new_status = (curr_status | WRITE_LOCKED) & (~WAIT_WRITE);
                 prev_status = apr_atomic_cas(lock, new_status, curr_status);
                 init(lock, new_status);
                 if (prev_status == curr_status) {
@@ -71,12 +71,16 @@ public:
                 if (((try_count++ & TIMEOUT_CHECK_MASK) == 0) &&
                     should_timeout(curr_status)) {
                     // タイムアウトしたら age を増やす
-                    new_status = (curr_status | WRITE_LOCKED) + AGE_UINIT;
+                    new_status = (curr_status | WRITE_LOCKED) & (~WAIT_WRITE);
+                    new_status += AGE_UINIT;
                     prev_status = apr_atomic_cas(lock, new_status, curr_status);
                     init(lock, new_status);
                     if (prev_status == curr_status) {
                         log_try_count("WriteLock(TIME OUT)",
                                       try_count, curr_status, new_status);
+#ifdef DEBUG_ReadWriteLocker
+                        is_process_timeout_ = true;
+#endif
                         return;
                     }
                 }
@@ -101,7 +105,7 @@ public:
         try_count = 1;
         while (1) {
             curr_status = apr_atomic_read(lock);
-            if (UNLIKELY(is_timeout(curr_status, status_))) {
+            if (UNLIKELY(is_others_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
                 log_try_count("WriteUnLock(TIME OUT)",
                               try_count, curr_status, curr_status);
