@@ -22,13 +22,17 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: mod_uploader.h 2712 2007-11-30 15:58:42Z svn $
  *****************************************************************************/
 
 #ifndef MOD_UPLOADER_H
 #define MOD_UPLOADER_H
 
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+extern "C" module MODULE_VAR_EXPORT uploader_module;
+#else
 extern "C" module AP_MODULE_DECLARE_DATA uploader_module;
+#endif
 
 #endif
 
