@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: uploader_handler.h 2712 2007-11-30 15:58:42Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_HANDLER_H
@@ -37,8 +37,7 @@
 
 template<class Response>
 int uploader_command_handler(typename Response::Handle *r,
-                             UploaderConfig *config,
-                             const char *arg);
+                             UploaderConfig *config, const char *arg);
 
 #endif
 
