@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.h 2661 2007-11-16 16:42:38Z svn $
+ * $Id: uploader_util.h 2683 2007-11-17 22:13:46Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_UTIL_H
@@ -36,6 +36,13 @@
 #include "Auxiliary.h"
 #include "Message.h"
 
+#define is_text_content(content)                            \
+    ((content != NULL) &&                                   \
+     (content->type == MultipartMessageParser<R>::TEXT))
+#define is_file_content(content)                            \
+    ((content != NULL) &&                                   \
+     (content->type == MultipartMessageParser<R>::FILE))
+
 class UploaderConfig;
 
 static const char POST_ID_PARAM[]                   = "id";
@@ -84,8 +91,7 @@ void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
     code_pat_content = MultipartMessageParser<R>::get_content
         (content_array, POST_CODE_PAT_PARAM);
 
-    if ((file_content == NULL) ||
-        (file_content->type != MultipartMessageParser<R>::FILE)) {
+    if (!is_file_content(file_content)) {
         THROW(MESSAGE_POST_DATA_INVALID);
     }
 
@@ -95,33 +101,14 @@ void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
     *file_digest    = file_content->file.digest;
     *file_temp_path = file_content->file.temp_path;
 
-    if ((comment_content == NULL) ||
-        (comment_content->type != MultipartMessageParser<R>::TEXT)) {
-        *comment = "";
-    } else {
-        *comment = comment_content->text;
-    }
-
-    if ((remove_pass_content == NULL) ||
-        (remove_pass_content->type != MultipartMessageParser<R>::TEXT)) {
-        *remove_pass = "";
-    } else {
-        *remove_pass = remove_pass_content->text;
-    }
-
-    if ((download_pass_content == NULL) ||
-        (download_pass_content->type != MultipartMessageParser<R>::TEXT)) {
-        *download_pass = "";
-    } else {
-        *download_pass = download_pass_content->text;
-    }
-
-    if ((code_pat_content == NULL) ||
-        (code_pat_content->type != MultipartMessageParser<R>::TEXT)) {
-        *code_pat = "";
-    } else {
-        *code_pat = code_pat_content->text;
-    }
+    *comment = is_text_content(comment_content) ?
+        *comment = comment_content->text : "";
+    *remove_pass = is_text_content(remove_pass_content) ?
+        *remove_pass = remove_pass_content->text : "";
+    *download_pass = is_text_content(download_pass_content) ?
+        *download_pass = download_pass_content->text : "";
+    *code_pat = is_text_content(code_pat_content) ?
+        *code_pat = code_pat_content->text : "";
 }
 
 template<class R>
@@ -187,8 +174,7 @@ const char *get_download_password(apr_pool_t *pool,
     content = MultipartMessageParser<R>::get_content(content_array,
                                                      POST_DOWNLOAD_PASS_PARAM);
 
-    if ((content == NULL) ||
-        (content->type != MultipartMessageParser<R>::TEXT)) {
+    if (!is_text_content(content)) {
         THROW(MESSAGE_POST_DATA_INVALID);
     }
 
@@ -207,10 +193,7 @@ void get_remove_param(apr_pool_t *pool, apr_array_header_t *content_array,
     remove_pass_content = MultipartMessageParser<R>::get_content
         (content_array, POST_REMOVE_PASS_PARAM);
 
-    if ((id_content == NULL) ||
-        (id_content->type != MultipartMessageParser<R>::TEXT) ||
-        (id_content == NULL) ||
-        (id_content->type != MultipartMessageParser<R>::TEXT)) {
+    if (!is_text_content(id_content)) {
         THROW(MESSAGE_POST_DATA_INVALID);
     }
 
