@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheLogger.cpp 2469 2007-06-30 06:39:24Z svn $
+ * $Id: ApacheLogger.cpp 2736 2007-12-09 06:46:23Z svn $
  *****************************************************************************/
 
 // Apache の config.h を先に処理させるため，httpd.h のインクルードはこの位置
@@ -35,10 +35,24 @@
 #include "ApacheLogger.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheLogger.cpp 2469 2007-06-30 06:39:24Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheLogger.cpp 2736 2007-12-09 06:46:23Z svn $");
 
 ApacheLogger logger;
 
+////////// Apache 1.x 用 //////////////////////////////////////////////
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
+#define AP_LOG_ERROR(file, line, level, status, s, fmt, ...)    \
+    ap_log_error(file, line, level, s, fmt, __VA_ARGS__)
+#define AP_LOG_RERROR(file, line, level, status, r_wrapper, fmt, ...)   \
+    ap_log_rerror(file, line, level, r_wrapper->r, fmt, __VA_ARGS__)
+////////// Apache 2.x 用 //////////////////////////////////////////////
+#else
+#define AP_LOG_ERROR ap_log_error
+#define AP_LOG_RERROR ap_log_rerror
+#endif
+///////////////////////////////////////////////////////////////////////
+
+
 /******************************************************************************
  * public メソッド
  ****************************************************************************/
@@ -53,7 +67,7 @@ void ApacheLogger::info(const char *file, int line, server_rec *s,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_error(file, line, APLOG_INFO, 0, s, "%s", message);
+    AP_LOG_ERROR(file, line, APLOG_INFO, 0, s, "%s", message);
 }
 
 void ApacheLogger::warn(const char *file, int line, server_rec *s,
@@ -67,7 +81,7 @@ void ApacheLogger::warn(const char *file, int line, server_rec *s,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_error(file, line, APLOG_WARNING, 0, s, "%s", message);
+    AP_LOG_ERROR(file, line, APLOG_WARNING, 0, s, "%s", message);
 }
 
 void ApacheLogger::error(const char *file, int line, server_rec *s,
@@ -81,11 +95,11 @@ void ApacheLogger::error(const char *file, int line, server_rec *s,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_error(file, line, APLOG_ERR, 0, s, "%s", message);
+    AP_LOG_ERROR(file, line, APLOG_ERR, 0, s, "%s", message);
 }
 
-void ApacheLogger::info(const char *file, int line, request_rec *r,
-                        const char *format, ...)
+void ApacheLogger::info(const char *file, int line,
+                        ApacheResponse::Handle *r, const char *format, ...)
 {
     TemporaryPool temp_pool;
     const char *message;
@@ -95,11 +109,11 @@ void ApacheLogger::info(const char *file, int line, request_rec *r,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_rerror(file, line, APLOG_INFO, 0, r, "%s", message);
+    AP_LOG_RERROR(file, line, APLOG_INFO, 0, r, "%s", message);
 }
 
-void ApacheLogger::warn(const char *file, int line, request_rec *r,
-                        const char *format, ...)
+void ApacheLogger::warn(const char *file, int line,
+                        ApacheResponse::Handle *r, const char *format, ...)
 {
     TemporaryPool temp_pool;
     const char *message;
@@ -109,11 +123,11 @@ void ApacheLogger::warn(const char *file, int line, request_rec *r,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_rerror(file, line, APLOG_WARNING, 0, r, "%s", message);
+    AP_LOG_RERROR(file, line, APLOG_WARNING, 0, r, "%s", message);
 }
 
-void ApacheLogger::error(const char *file, int line, request_rec *r,
-                         const char *format, ...)
+void ApacheLogger::error(const char *file, int line,
+                         ApacheResponse::Handle *r, const char *format, ...)
 {
     TemporaryPool temp_pool;
     const char *message;
@@ -123,7 +137,7 @@ void ApacheLogger::error(const char *file, int line, request_rec *r,
     message = apr_pvsprintf(temp_pool.get(), format, args);
     va_end(args);
 
-    ap_log_rerror(file, line, APLOG_ERR, 0, r, "%s", message);
+    AP_LOG_RERROR(file, line, APLOG_ERR, 0, r, "%s", message);
 }
 
 // Local Variables:
