@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRequestReader.cpp 2461 2007-06-29 18:09:05Z svn $
+ * $Id: ApacheRequestReader.cpp 2714 2007-12-01 12:27:48Z svn $
  *****************************************************************************/
 
 #include "ApacheRequestReader.h"
@@ -38,17 +38,53 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2461 2007-06-29 18:09:05Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2714 2007-12-01 12:27:48Z svn $");
 
 const apr_size_t ApacheRequestReader::READ_SLEEP_FACTOR = 16;
 const apr_size_t ApacheRequestReader::READ_SLEEP_USEC   = 100000;
 
+////////// Apache 1.x 用 //////////////////////////////////////////////
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
 ApacheRequestReader::ApacheRequestReader(post_progress_t *progress,
-                                         request_rec *request)
+                                         ApacheResponse::Handle *request)
+    : RequestReader(progress),
+      request_(request),
+      brigade_(NULL),
+      bucket_(NULL),
+      is_eos_(false)
+{
+
+}
+
+void ApacheRequestReader::read(char *buffer, apr_size_t size, apr_size_t *read_size)
+{
+    if (is_eos_) {
+        *read_size = 0;
+        return;
+    }
+
+    if ((*read_size = ap_get_client_block(request_->r, buffer, size)) == 0) {
+        is_eos_ = true;
+    }
+}
+
+ApacheRequestReader::~ApacheRequestReader()
+{
+
+}
+
+////////// Apache 2.x 用 //////////////////////////////////////////////
+#else
+
+/******************************************************************************
+ * public メソッド
+ *****************************************************************************/
+ApacheRequestReader::ApacheRequestReader(post_progress_t *progress,
+                                         ApacheResponse::Handle *request)
     : RequestReader(progress),
       request_(request),
       brigade_(apr_brigade_create(request->pool,
@@ -122,6 +158,9 @@ void ApacheRequestReader::get_brigade()
     bucket_ = APR_BRIGADE_FIRST(brigade_);
 }
 
+#endif
+///////////////////////////////////////////////////////////////////////
+
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
