@@ -22,17 +22,20 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.cpp 2540 2007-07-21 15:21:47Z svn $
+ * $Id: ApacheResponseWriter.cpp 2717 2007-12-01 17:32:02Z svn $
  *****************************************************************************/
 
 // Apache の config.h を先に処理させるため，util_filter.h の
 // インクルードはこの位置
+#include "httpd.h"
 #include "http_protocol.h"
-#include "util_filter.h"
 
 #include "Environment.h"
 
-#include "httpd.h"
+#if AP_SERVER_MAJORVERSION_NUMBER != 1
+#include "util_filter.h"
+#endif
+
 #include "http_config.h"
 #define CORE_PRIVATE
 #include "http_core.h"
@@ -40,12 +43,90 @@
 #include "ApacheResponseWriter.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2540 2007-07-21 15:21:47Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2717 2007-12-01 17:32:02Z svn $");
+
+////////// Apache 1.x 用 //////////////////////////////////////////////
+#if AP_SERVER_MAJORVERSION_NUMBER == 1
 
 /******************************************************************************
  * public メソッド
  ****************************************************************************/
-ApacheResponseWriter::ApacheResponseWriter(request_rec *r)
+ApacheResponseWriter::ApacheResponseWriter(ApacheResponse::Handle *r)
+  : connection_(r->r->connection),
+    brigade_(reinterpret_cast<apr_bucket_brigade *>(r)), // :-)
+    filter_(NULL),
+    iovec_count_(0)
+{
+    pool_ = r->pool;
+}
+
+ApacheResponseWriter::ApacheResponseWriter(ApacheResponseWriter& writer)
+  : connection_(writer.connection_),
+    brigade_(writer.brigade_),
+    filter_(writer.filter_),
+    iovec_count_(writer.iovec_count_)
+{
+    pool_ = writer.pool_;
+}
+
+ApacheResponseWriter::~ApacheResponseWriter()
+{
+    flush();
+}
+
+void ApacheResponseWriter::finish()
+{
+    flush();
+}
+
+bool ApacheResponseWriter::is_sendfile_enabled(ApacheResponse::Handle *r)
+{
+    return false;
+}
+
+int ApacheResponseWriter::sendfile(ApacheResponse::Handle *r, apr_file_t *file,
+                                   apr_uint64_t length)
+{
+    apr_mmap_t *mmap;
+    TemporaryPool temp_pool;
+
+    if (apr_mmap_create(&mmap, file, 0,
+                        static_cast<apr_size_t>(length), APR_MMAP_READ,
+                        temp_pool.get()) != APR_SUCCESS) {
+        THROW(MESSAGE_FILE_MMAP_FAILED);
+    }
+
+    ap_send_mmap(mmap->mm, r->r, 0, length);
+
+    return OK;
+}
+
+/******************************************************************************
+ * private メソッド
+ ****************************************************************************/
+void ApacheResponseWriter::flush()
+{
+    if (UNLIKELY((iovec_count_ == 0) || connection_->aborted)) {
+        iovec_count_ = 0;
+        return;
+    }
+
+    for (apr_size_t i = 0; i < iovec_count_; i++) {
+        ap_rwrite(iovec_[i].iov_base,
+                  iovec_[i].iov_len,
+                  reinterpret_cast<ApacheResponse::Handle *>(brigade_)->r); // :-)
+    }
+
+    iovec_count_ = 0;
+}
+
+////////// Apache 2.x 用 //////////////////////////////////////////////
+#else
+
+/******************************************************************************
+ * public メソッド
+ ****************************************************************************/
+ApacheResponseWriter::ApacheResponseWriter(ApacheResponse::Handle *r)
   : connection_(r->connection),
     brigade_(apr_brigade_create(r->pool, r->connection->bucket_alloc)),
     filter_(r->output_filters),
@@ -79,7 +160,7 @@ void ApacheResponseWriter::finish()
     ap_filter_flush(brigade_, filter_);
 }
 
-bool ApacheResponseWriter::is_sendfile_enabled(request_rec *r)
+bool ApacheResponseWriter::is_sendfile_enabled(ApacheResponse::Handle *r)
 {
 #if APR_HAS_SENDFILE
     core_dir_config *core_config;
@@ -93,7 +174,7 @@ bool ApacheResponseWriter::is_sendfile_enabled(request_rec *r)
 #endif
 }
 
-int ApacheResponseWriter::sendfile(request_rec *r, apr_file_t *file,
+int ApacheResponseWriter::sendfile(ApacheResponse::Handle *r, apr_file_t *file,
                                    apr_uint64_t length)
 {
     conn_rec *connection;
@@ -145,7 +226,7 @@ int ApacheResponseWriter::sendfile(request_rec *r, apr_file_t *file,
 
 
 /******************************************************************************
- * public メソッド
+ * private メソッド
  ****************************************************************************/
 void ApacheResponseWriter::flush()
 {
@@ -160,7 +241,7 @@ void ApacheResponseWriter::flush()
     iovec_count_ = 0;
 }
 
-bool ApacheResponseWriter::is_mmap_enabled(request_rec *r)
+bool ApacheResponseWriter::is_mmap_enabled(ApacheResponse::Handle *r)
 {
 #if APR_HAS_MMAP
     core_dir_config *core_config;
@@ -174,6 +255,9 @@ bool ApacheResponseWriter::is_mmap_enabled(request_rec *r)
 #endif
 }
 
+#endif
+///////////////////////////////////////////////////////////////////////
+
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
