@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2666 2007-11-16 21:02:54Z svn $
+ * $Id: Auxiliary.cpp 2687 2007-11-18 02:15:39Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2666 2007-11-16 21:02:54Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2687 2007-11-18 02:15:39Z svn $");
 
 const char *rfc2396_encode(apr_pool_t *pool, const char* str)
 {
@@ -378,16 +378,16 @@ const char *escape_html(apr_pool_t *pool, const char *str)
 
 const char *size_str(apr_pool_t *pool, apr_uint64_t size)
 {
-    static const long int CMP_FACTOR    = 1024;
+    static const apr_size_t CMP_FACTOR  = 1024;
     apr_size_t temp_size;
     const char *unit_str;
 
     // MEMO: 約 400 TB 以上だと桁あふれして誤動するので注意
 
     do {
-        if (size > (1024*1024*1024)) {
+        if (size > (1024LL*1024*1024)) {
             temp_size = static_cast<apr_size_t>(size /
-                                                (1024*1024*1024/CMP_FACTOR));
+                                                (1024LL*1024*1024/CMP_FACTOR));
             unit_str = GBYTE_UNIT;
             break;
         }
@@ -405,7 +405,7 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
         }
     } while (0);
 
-    return apr_psprintf(pool, "%ld.%ld %s",
+    return apr_psprintf(pool, "%" APR_SIZE_T_FMT ".%" APR_SIZE_T_FMT " %s",
                         temp_size / CMP_FACTOR,
                         (temp_size * 10 / CMP_FACTOR) % 10,
                         unit_str);
