@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $
+ * $Id: BasicFileWriter.cpp 2595 2007-10-22 14:36:13Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,7 +34,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: BasicFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $");
+SOURCE_INFO_ADD("$Id: BasicFileWriter.cpp 2595 2007-10-22 14:36:13Z svn $");
 #endif
 
 /******************************************************************************
@@ -50,12 +50,11 @@ BasicFileWriter::BasicFileWriter(apr_pool_t *pool, apr_file_t *file,
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void BasicFileWriter::write_impl(const void *buffer, apr_size_t size)
+apr_size_t BasicFileWriter::write_impl(const void *buffer, apr_size_t size)
 {
-    apr_size_t write_size;
+    file_->write(buffer, &size);
 
-    write_size = size;
-    file_->write(buffer, &write_size);
+    return size;
 }
 
 
