@@ -22,23 +22,17 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CharCodeConverter.cpp 2615 2007-10-29 14:37:48Z svn $
+ * $Id: CharCodeConverter.cpp 2665 2007-11-16 19:21:35Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
-#ifndef WIN32
-#ifdef HAVE_ICONV_H
-#ifndef APU_HAVE_ICONV
-#define APU_HAVE_ICONV 1
-#endif
-#endif
-#endif
+#include "apu.h"
 
-#if APU_HAVE_ICONV
-#include <iconv.h>
-#elif APU_HAVE_APR_ICONV
+#if APU_HAVE_APR_ICONV
 #include "apr_iconv.h"
+#elif APU_HAVE_ICONV
+#include <iconv.h>
 #endif
 #include "apr_strings.h"
 
@@ -47,7 +41,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: CharCodeConverter.cpp 2615 2007-10-29 14:37:48Z svn $");
+SOURCE_INFO_ADD("$Id: CharCodeConverter.cpp 2665 2007-11-16 19:21:35Z svn $");
 
 const char CharCodeConverter::DEFAULT_CODE[]            = SYS_CHARACTER_CODE;
 const unsigned char CharCodeConverter::EUCJP_PAT_FIRST  = 0xb5;
@@ -69,24 +63,7 @@ const char *CharCodeConverter::convert(apr_pool_t *pool, const char *str,
 {
     char *converted;
 
-#if APU_HAVE_ICONV
-    char *buffer;
-    ICONV_2ND_ARG_TYPE target;
-    size_t str_len = strlen(str);
-    size_t buffer_len = str_len * 3;
-    iconv_t handle;
-
-    target = static_cast<ICONV_2ND_ARG_TYPE>(apr_pstrdup(pool, str));
-    converted = buffer = static_cast<char *>(apr_pcalloc(pool, buffer_len));
-    buffer_len--;
-
-    if ((handle = iconv_open(to, from)) == reinterpret_cast<iconv_t>(-1)) {
-        throw apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
-                          "(", from, " -> ", to, ")", NULL);
-    }
-    iconv(handle, &target, &str_len, &buffer, &buffer_len);
-    iconv_close(handle);
-#elif APU_HAVE_APR_ICONV
+#if APU_HAVE_APR_ICONV
     char *buffer;
     apr_size_t str_len = strlen(str);
     apr_size_t buffer_len = str_len * 3;
@@ -103,6 +80,23 @@ const char *CharCodeConverter::convert(apr_pool_t *pool, const char *str,
     apr_iconv(handle,
               &str, &str_len, &buffer, &buffer_len, &converted_len);
     apr_iconv_close(handle, pool);
+#elif APU_HAVE_ICONV
+    char *buffer;
+    ICONV_2ND_ARG_TYPE target;
+    size_t str_len = strlen(str);
+    size_t buffer_len = str_len * 3;
+    iconv_t handle;
+
+    target = static_cast<ICONV_2ND_ARG_TYPE>(apr_pstrdup(pool, str));
+    converted = buffer = static_cast<char *>(apr_pcalloc(pool, buffer_len));
+    buffer_len--;
+
+    if ((handle = iconv_open(to, from)) == reinterpret_cast<iconv_t>(-1)) {
+        throw apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
+                          "(", from, " -> ", to, ")", NULL);
+    }
+    iconv(handle, &target, &str_len, &buffer, &buffer_len);
+    iconv_close(handle);
 #else
 
     // iconv，apr_iconv が無い場合，文字コード変換は行わない
