@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC2822Parser.cpp 2595 2007-10-22 14:36:13Z svn $
+ * $Id: RFC2822Parser.cpp 2681 2007-11-17 22:11:26Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -38,8 +38,10 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
+using namespace std;
+
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2595 2007-10-22 14:36:13Z svn $");
+SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2681 2007-11-17 22:11:26Z svn $");
 #endif
 
 #ifdef DEBUG_RFC2822Parser
@@ -272,7 +274,6 @@ void RFC2822Parser<R, W>::parse_header()
 
 #include "File.h"
 #include "CGIRequestReader.h"
-#include "BasicFileWriter.h"
 
 #define TEMPLATE_INSTANTIATION
 #include "MultipartMessageParser.cpp"
@@ -286,8 +287,6 @@ static const apr_size_t MAX_FILE_SIZE   = 100 * 1024 * 1024;
 static const apr_size_t MAX_ITEM_NUM    = 10;
 
 typedef RFC2822Parser<CGIRequestReader> RFC2822ParserImpl;
-typedef MultipartMessageParser<CGIRequestReader,
-                               Base64FileWriter<BasicFileWriter> > MessageParserImpl;
 
 void show_usage(const char *prog_name)
 {
@@ -316,7 +315,7 @@ void run_parse(apr_pool_t *pool, const char *post_file_path,
         RFC2822ParserImpl::dump_content_array(content_array);
     }
 
-    file_content = MessageParserImpl::get_content(content_array,
+    file_content = RFC2822ParserImpl::get_content(content_array,
                                                   FILE_CONTENT_NAME);
     if (file_digest != NULL) {
         if (strncmp(file_content->file.digest, file_digest,
