@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2676 2007-11-17 15:03:20Z svn $
+ * $Id: UploadItem.cpp 2705 2007-11-25 01:22:41Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2676 2007-11-17 15:03:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2705 2007-11-25 01:22:41Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -90,6 +90,10 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
     uitem->header_.mtime        = mtime;
     uitem->header_.file_size    = file_size;
 
+#ifdef USE_GZIP
+    uitem->header_.is_gzipped   = 1;
+#endif
+
     strncpy(uitem->header_.date, date, ITM_MAX_DATE_SIZE);
     strncpy(uitem->header_.ip_address, ip_address, ITM_MAX_IP_ADDRESS_SIZE);
     strncpy(uitem->header_.file_name, file_name, ITM_MAX_FILE_NAME_SIZE);
