@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.cpp 2506 2007-07-06 18:21:58Z svn $
+ * $Id: uploader_util.cpp 2661 2007-11-16 16:42:38Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: uploader_util.cpp 2506 2007-07-06 18:21:58Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_util.cpp 2661 2007-11-16 16:42:38Z svn $");
 
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter)
@@ -87,28 +87,6 @@ void get_page(apr_pool_t *pool, const char *arg, apr_size_t page_count,
     }
 }
 
-const char *get_dispos_encoding(const char *user_agent)
-{
-    const char *encoding;
-
-    encoding = CharCodeConverter::DEFAULT_CODE;
-
-    if (user_agent == NULL) {
-        return encoding;
-    }
-
-    // だー．激しく場当たり的．
-    if ((strstr(user_agent, "compatible; MSIE") != NULL) ||
-        (strstr(user_agent, "Sleipnir") != NULL)) {
-        encoding = IE_NAME_ENCODING;
-    } else if ((strstr(user_agent, "Firefox") != NULL) ||
-               (strstr(user_agent, "Mozilla") != NULL)) {
-        encoding = FIREFOX_NAME_ENCODING;
-    }
-
-    return encoding;
-}
-
 bool can_post(UploaderConfig *config, apr_sockaddr_t *ip_address)
 {
     if (config->is_debug_mode) {
